svn commit: r393830 - in head/ports-mgmt/portlint: . src
Joe Marcus Clarke
marcus at FreeBSD.org
Sun Aug 9 22:23:27 UTC 2015
Author: marcus
Date: Sun Aug 9 22:23:26 2015
New Revision: 393830
URL: https://svnweb.freebsd.org/changeset/ports/393830
Log:
Update to 2.16.6.
* Only report "make makepatch" once per patch file [1]
* Attempt to re-word the make makepatch warning to avoid unnecessary repo
churn [2]
* Attempt to test some other macros for sorting [3]
* Do not check empty dependencies for validity [4]
PR: 202050 [1]
201647 [2]
201409 [3]
202052 [4]
Submitted by: gerald [1]
Modified:
head/ports-mgmt/portlint/Makefile
head/ports-mgmt/portlint/src/portlint.pl
Modified: head/ports-mgmt/portlint/Makefile
==============================================================================
--- head/ports-mgmt/portlint/Makefile Sun Aug 9 21:46:54 2015 (r393829)
+++ head/ports-mgmt/portlint/Makefile Sun Aug 9 22:23:26 2015 (r393830)
@@ -2,7 +2,7 @@
# $FreeBSD$
PORTNAME= portlint
-PORTVERSION= 2.16.5
+PORTVERSION= 2.16.6
CATEGORIES= ports-mgmt
MASTER_SITES= # none
DISTFILES= # none
Modified: head/ports-mgmt/portlint/src/portlint.pl
==============================================================================
--- head/ports-mgmt/portlint/src/portlint.pl Sun Aug 9 21:46:54 2015 (r393829)
+++ head/ports-mgmt/portlint/src/portlint.pl Sun Aug 9 22:23:26 2015 (r393830)
@@ -15,7 +15,7 @@
# was removed.
#
# $FreeBSD$
-# $MCom: portlint/portlint.pl,v 1.366 2015/07/06 14:48:28 jclarke Exp $
+# $MCom: portlint/portlint.pl,v 1.371 2015/08/09 22:21:09 jclarke Exp $
#
use strict;
@@ -50,7 +50,7 @@ $portdir = '.';
# version variables
my $major = 2;
my $minor = 16;
-my $micro = 5;
+my $micro = 6;
# default setting - for FreeBSD
my $portsdir = '/usr/ports';
@@ -933,8 +933,10 @@ sub checkpatch {
if ($_ !~ /UTC\s*$/) {
&perror("WARN", $file, -1, "patch was not generated using ".
"``make makepatch''. It is recommended to use ".
- "``make makepatch'' to ensure proper patch format.");
+ "``make makepatch'' when you need to [re-]generate a ".
+ "patch to ensure proper patch format.");
}
+ last;
}
}
@@ -983,6 +985,9 @@ sub check_depends_syntax {
if ($k =~ /^\$\{(\w+)\}$/) {
$k = get_makevar($1);
}
+ if ($k eq '') {
+ next;
+ }
my @l = split(':', $k);
print "OK: checking dependency value for $j.\n"
@@ -1644,16 +1649,23 @@ sub checkmakefile {
}
#
# whole file: Check if USES is sorted
#
- print "OK: checking to see if USES is sorted.\n" if ($verbose);
- while ($whole =~ /\nUSES.?=\s*(.+)\n/g) {
- my $lineno = &linenumber($`);
- my $srex = $1;
- my @suses = sort(split / /, $srex);
- if (join(" ", @suses) ne $srex) {
- &perror("WARN", $file, $lineno, "the options to USES are not ".
- "sorted. Please consider sorting them.");
+ my @uses_to_sort = qw(
+ USES
+ USE_PYTHON
+ USE_XORG
+ );
+ print "OK: checking to see if USES_* stuff is sorted.\n" if ($verbose);
+ foreach my $sorted_use (@uses_to_sort) {
+ while ($whole =~ /\n$sorted_use.?=\s*(.+)\n/g) {
+ my $lineno = &linenumber($`);
+ my $srex = $1;
+ my @suses = sort(split / /, $srex);
+ if (join(" ", @suses) ne $srex) {
+ &perror("WARN", $file, $lineno, "the options to $sorted_use ".
+ "are not sorted. Please consider sorting them.");
+ }
}
}
More information about the svn-ports-head
@@ -1644,16 +1649,23 @@ sub checkmakefile {
}
#
- # whole file: Check if USES is sorted
+ # whole file: Check if USES stuff is sorted
#
mailing list